/**
 * Beispielsprogramm zur Demonstration des JDBC-APIs.
 *
 * @author: Thomas Brinkhoff
 * @version: 1.00
 */

import java.sql.*;		// Import der Klassen des Pakets "java.sql.*"

import static gdbutil.ConnectionParameters.*;

public class JdbcExample {

public static void main (String[] args) {
	try {
		// Verbindung zur Datenbank aufbauen
		//Class.forName("oracle.jdbc.driver.OracleDriver");  // ab JDK6 entbehrlich
			// fr JDBC-ODBC-Bridge: Class.forName("sun.jdbc.odbc.JdbcOdbcDriver");
		String url = "jdbc:oracle:thin:@" + DBHOST + ":" + DBPORT + ":" + DBNAME;  // JDBC Thin Driver
			// bei JDBC-ODBC-Bridge: "jdbc:odbc:" + ODBCDSN;
			// bei JDBC OCI Driver:  "jdbc:oracle:oci:@" + DBSERVICENAME;
		Connection db = DriverManager.getConnection(url, DBUSER, DBPASSWORD);

		// Einfache Anfrage ausfhren
		Statement statement = db.createStatement();
		String sql = "SELECT gkz,name FROM Gemeinden WHERE name LIKE 'Ol%'";
		ResultSet result = statement.executeQuery(sql);
		while (result.next()) {
			System.out.print(result.getInt("gkz") + " - ");
			System.out.println(result.getString(2));
		}
		result.close();
		statement.close();
		System.out.println();

		// PreparedStatement ausfhren
		sql = "SELECT name FROM Hochschulen WHERE stud >= ? AND stud < ?";
		PreparedStatement prepStmt = db.prepareStatement(sql);
		for (int i=0; i<30000; i+=10000) {
			prepStmt.setInt(1,i);
			prepStmt.setInt(2,i+10000);
			result = prepStmt.executeQuery();
			System.out.println("zw. "+i+" und "+(i+10000)+" Studierende:");
			while (result.next())
				System.out.println("  "+result.getString("name"));
			result.close();
		}
		prepStmt.close();
		System.out.println();

		// Gespeicherte Funktion aufrufen
		sql = "{? = call kreisstadttext(?)}";
		CallableStatement callStmt = db.prepareCall(sql);
		callStmt.registerOutParameter(1,java.sql.Types.VARCHAR);
		callStmt.setString(2,"Ammerland");
		callStmt.execute();
		System.out.println("Ammerland -> "+callStmt.getString(1));
		callStmt.setString(2,null);
		callStmt.execute();
		System.out.println("null      -> "+callStmt.getString(1));
		callStmt.close();
		System.out.println();

		// Daten verndern
		Statement update = db.createStatement();
		int stud = 7000;
		sql = "UPDATE Hochschulen SET stud = "+stud+" WHERE name = 'Jade Hochschule'";
		int n = update.executeUpdate(sql);
		System.out.println("Zahl genderter Datenstze: "+n);
		update.close();

		// Verbindung schlieen
		db.close();
	} // try

	// Fehlerbehandlung, falls die Klasse nicht gefunden wird
	/*catch (Exception ex) {
		System.err.println("JdbcExample.main: "+ex);
	}*/
	// Fehler beim Datenbankzugriff behandeln
	catch (SQLException ex) {
		System.err.println("JdbcExample.main: "+ex);
	}
}
}
