import static gdbutil.ConnectionParameters.*;

import java.sql.*;

import oracle.spatial.geometry.ElementExtractor;
import oracle.spatial.geometry.J3D_Geometry;
import oracle.spatial.geometry.JGeometry;

/**
 * Klasse zum Einlesen der Dreiecke der Dreiecksvermaschung.
 *
 * @author: Thomas Brinkhoff, http://www.geodbs.de/
 */
public class ReadTIN {

public static void main (String[] args) {
	try {
		// Verbindung zur Datenbank aufbauen
		String url = "jdbc:oracle:thin:@" + DBHOST + ":" + DBPORT + ":" + DBNAME;  // JDBC Thin Driver
			// bei JDBC OCI Driver:  "jdbc:oracle:oci:@" + DBSERVICENAME;
		Connection db = DriverManager.getConnection(url, DBUSER, DBPASSWORD);

		// Anfrage ausfhren
		Statement statement = db.createStatement();
		String sql = "SELECT SDO_TIN_PKG.TO_GEOMETRY(points,triangles,num_points,num_triangles,2,3,NULL) FROM TINBlockDaten";
		ResultSet result = statement.executeQuery(sql);
		// Blcke durchlaufen
		while (result.next()) {
			// Geometrie holen
			Struct struct = (Struct) result.getObject(1);
			JGeometry geom = JGeometry.loadJS(struct);
			// 3D-Geometrie erzeugen
			J3D_Geometry geom3D = new J3D_Geometry(geom.getType(), geom.getSRID(), geom.getElemInfo(), geom.getOrdinatesArray());
			// Teilgeometrien durchlaufen
			ElementExtractor ee = new ElementExtractor(geom3D);
			int[] type = new int[1];
			J3D_Geometry elem = ee.nextElement(type);
			while (elem != null) {
				double[] ord = elem.getOrdinatesArray();
				for (int i=0; i<ord.length/3-1; i++)  // letzte Koordinate nicht wiederholen
					System.out.print("("+ord[3*i]+","+ord[3*i+1]+","+ord[3*i+2]+") ");
				System.out.println("["+type[0]+"]");
				elem = ee.nextElement(type);
			}
		}
		// Anfrage und Verbindung schlieen
		result.close();
		statement.close();
		db.close();
	}
	// Fehler behandeln
	catch (Exception ex) {
		System.err.println("ReadTIN.main: " + ex);
		ex.printStackTrace();
	}
}
}
