/**
 * Beispielsprogramm zur Demonstration der API oracle.spatial.
 *
 * @author: Thomas Brinkhoff
 * @version: 1.00
 */

import static gdbutil.ConnectionParameters.*;

import java.awt.Shape;
import java.awt.geom.Point2D;
import java.sql.*;

import oracle.spatial.geometry.JGeometry;

public class SpatialExample {

public static void main (String[] args) {
	try {
		// Verbindung zur Datenbank aufbauen
		//Class.forName("oracle.jdbc.driver.OracleDriver");
		String url = "jdbc:oracle:thin:@" + DBHOST + ":" + DBPORT + ":" + DBNAME;  // JDBC Thin Driver
			// bei JDBC OCI Driver:  "jdbc:oracle:oci:@" + DBSERVICENAME;
		Connection db = DriverManager.getConnection(url, DBUSER, DBPASSWORD);

		// Anfrage ausfhren
		Statement statement = db.createStatement();
		String sql = "SELECT name,centrum,gebiet FROM Gemeinden WHERE gkz = 3403000";
		ResultSet result = statement.executeQuery(sql);
		int srid = 0;
		if (result.next()) {
			System.out.print(result.getString("name") + " - ");
			// Attribut "centrum"
			Struct struct = (Struct) result.getObject("centrum");
			JGeometry jGeom = JGeometry.loadJS(struct);
			System.out.println("Dimension: "+jGeom.getDimensions());
			System.out.println("Type: "+jGeom.getType());
			srid = jGeom.getSRID();
			System.out.println("SRID: "+srid);
			// Umwandlung in AWT-Point2D
			Point2D centrum = jGeom.getJavaPoint();
			System.out.println(centrum.getX()+" / "+centrum.getY());
			System.out.println();
			// Attribut "gebiet"
			struct = (Struct) result.getObject("gebiet");
			jGeom = JGeometry.loadJS(struct);
			System.out.println("Type: "+jGeom.getType());
			System.out.println("Kreis? "+jGeom.isCircle());
			System.out.println("#Punkte: "+jGeom.getNumPoints());
			double mbr[] = jGeom.getMBR();
			System.out.print("MUR: ");
			for (double mbrOrd : mbr)
				System.out.print(mbrOrd+" ");
			System.out.println();
			int elemInfo[] = jGeom.getElemInfo();
			System.out.print("ElemInfo: ");
			for (int elem : elemInfo)
				System.out.print(elem+" ");
			System.out.println();
			double ord[] = jGeom.getOrdinatesArray();
			System.out.println("coordinates: ");
			for (int i=0; i<ord.length/2; i++)
				System.out.print("("+ord[2*i]+" , "+ord[2*i+1]+") ");
			System.out.println();
			// Umwandlung in AWT-Shape
			Shape shape = jGeom.createShape();
			System.out.println("Shape: "+shape.getClass().getName());
		}
		result.close();
		// ggf. Helgoland lschen
		statement.executeUpdate("DELETE FROM Gemeinden WHERE name = 'Helgoland'");
		statement.close();
		// Einfgen vorbereiten
		sql = "INSERT INTO Gemeinden (gkz,name,einw,centrum,gebiet) VALUES (1056025,'Helgoland',1499,?,?)";
		PreparedStatement insert = db.prepareStatement(sql);
		// Punkt setzen
		JGeometry centrum = new JGeometry(7.936,54.204,srid);
		insert.setObject (1,JGeometry.storeJS(centrum,db));
		// Gebiet setzen
		double coords[] = {7.923,54.210, 7.944,54.194, 7.952,54.197, 7.945,54.209, 7.938,54.211, 7.923,54.210};
		JGeometry area = JGeometry.createLinearPolygon(coords,2, srid);
		insert.setObject (2,JGeometry.storeJS(area,db));
		// Einfgen
		insert.executeUpdate();
		insert.close();

		// Verbindung schlieen
		db.close();
	} // try

	// Fehlerbehandlung:
	catch (Exception ex) {
		System.err.println("SpatialExample.main: "+ex);
	}
}
}
